@@ -85,9 +85,10 @@ AppletsLayout::AppletsLayout(QQuickItem *parent)
                 m_layoutManager->layoutGeometryChanged(newGeom, m_geometryBeforeResolutionChange);
                 m_geometryBeforeResolutionChange = QRectF();
 
-                // Heuristically relayout items only when the plasma startup is fully completed
-            } else {
-                polish();
+                // If the user doesn't move a widget after this is done, the widget positions won't be saved and they will be in the wrong
+                // places on next login, so save them now.
+
+                save();
             }
         }
         m_layoutChanges = NoChange;
