@@ -58,7 +58,7 @@ public:
         , filterModel(w)
         , activitiesConsumer(new KActivities::Consumer())
     {
-        QObject::connect(activitiesConsumer.data(), &Consumer::currentActivityChanged, q, [this] {
+        QObject::connect(activitiesConsumer.get(), &Consumer::currentActivityChanged, q, [this] {
             initRunningApplets();
         });
     }
@@ -98,7 +98,7 @@ public:
     DefaultItemFilterProxyModel filterItemModel;
     static QPointer<KNS3::QtQuickDialogWrapper> newStuffDialog;
 
-    QScopedPointer<KActivities::Consumer> activitiesConsumer;
+    std::unique_ptr<KActivities::Consumer> activitiesConsumer;
 };
 
 QPointer<KNS3::QtQuickDialogWrapper> WidgetExplorerPrivate::newStuffDialog;
@@ -278,12 +278,9 @@ void WidgetExplorerPrivate::addContainment(Containment *containment)
     QObject::connect(containment, SIGNAL(appletAdded(Plasma::Applet *)), q, SLOT(appletAdded(Plasma::Applet *)));
     QObject::connect(containment, SIGNAL(appletRemoved(Plasma::Applet *)), q, SLOT(appletRemoved(Plasma::Applet *)));
 
-    foreach (Applet *applet, containment->applets()) {
+    const QList<Applet *> applets = containment->applets();
+    for (auto applet : applets) {
         if (applet->pluginMetaData().isValid()) {
-            Containment *childContainment = applet->property("containment").value<Containment *>();
-            if (childContainment) {
-                addContainment(childContainment);
-            }
             runningApplets[applet->pluginMetaData().pluginId()]++;
         } else {
             qDebug() << "Invalid plugin metadata. :(";
