@@ -1,23 +1,10 @@
 /*
- *   Copyright (C) 2007 Christopher Blauvelt <cblauvelt@gmail.com>
- *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License version 2 as
- *   published by the Free Software Foundation
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2007 Christopher Blauvelt <cblauvelt@gmail.com>
 
-#ifndef SOLIDDEVICEENGINE_H
-#define SOLIDDEVICEENGINE_H
+    SPDX-License-Identifier: LGPL-2.0-only
+*/
+
+#pragma once
 
 #include <QList>
 #include <QMap>
@@ -98,5 +85,3 @@ private Q_SLOTS:
     void setIdleState(Solid::ErrorType error, QVariant errorData, const QString &udi);
     void deviceChanged(const QMap<QString, int> &props);
 };
-
-#endif
